@@ -6,6 +6,9 @@
 # nor does it submit to any jurisdiction.
 #
 
+import logging
+
+LOG = logging.getLogger(__name__)
 
 PRIVATE_ATTRIBUTES = {"observer": lambda: None}
 
